==> azure-mgmt-batchai-1.7.0-sources.jar: com/microsoft/azure/management/batchai/BatchAIJobs.java <==
/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 */
package com.microsoft.azure.management.batchai;

import com.microsoft.azure.management.apigeneration.Beta;
import com.microsoft.azure.management.apigeneration.Fluent;
import com.microsoft.azure.management.batchai.implementation.JobsInner;
import com.microsoft.azure.management.resources.fluentcore.arm.collection.SupportsGettingById;
import com.microsoft.azure.management.resources.fluentcore.arm.collection.SupportsGettingByName;
import com.microsoft.azure.management.resources.fluentcore.arm.collection.SupportsGettingByNameAsync;
import com.microsoft.azure.management.resources.fluentcore.arm.models.HasParent;
import com.microsoft.azure.management.resources.fluentcore.collection.SupportsCreating;
import com.microsoft.azure.management.resources.fluentcore.collection.SupportsDeletingById;
import com.microsoft.azure.management.resources.fluentcore.collection.SupportsDeletingByName;
import com.microsoft.azure.management.resources.fluentcore.collection.SupportsListing;
import com.microsoft.azure.management.resources.fluentcore.model.HasInner;

/**
 * Entry point for Batch AI jobs management API in Azure.
 */
@Fluent
@Beta(Beta.SinceVersion.V1_6_0)
public interface BatchAIJobs extends
        SupportsCreating<BatchAIJob.DefinitionStages.Blank>,
        SupportsListing<BatchAIJob>,
        SupportsGettingByName<BatchAIJob>,
        SupportsGettingById<BatchAIJob>,
        SupportsGettingByNameAsync<BatchAIJob>,
        SupportsDeletingByName,
        SupportsDeletingById,
        HasInner<JobsInner>,
        HasParent<BatchAICluster> {
}

==> azure-mgmt-batchai-1.24.2-sources.jar: com/microsoft/azure/management/batchai/BatchAIJobs.java <==
/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 */
package com.microsoft.azure.management.batchai;

import com.microsoft.azure.PagedList;
import com.microsoft.azure.management.apigeneration.Beta;
import com.microsoft.azure.management.apigeneration.Fluent;
import com.microsoft.azure.management.batchai.implementation.BatchAIManager;
import com.microsoft.azure.management.batchai.implementation.JobsInner;
import com.microsoft.azure.management.resources.fluentcore.arm.collection.SupportsGettingById;
import com.microsoft.azure.management.resources.fluentcore.arm.collection.SupportsGettingByName;
import com.microsoft.azure.management.resources.fluentcore.arm.collection.SupportsGettingByNameAsync;
import com.microsoft.azure.management.resources.fluentcore.arm.models.HasManager;
import com.microsoft.azure.management.resources.fluentcore.arm.models.HasParent;
import com.microsoft.azure.management.resources.fluentcore.collection.SupportsCreating;
import com.microsoft.azure.management.resources.fluentcore.collection.SupportsDeletingById;
import com.microsoft.azure.management.resources.fluentcore.collection.SupportsDeletingByName;
import com.microsoft.azure.management.resources.fluentcore.collection.SupportsListing;
import com.microsoft.azure.management.resources.fluentcore.model.HasInner;

/**
 * Entry point for Batch AI jobs management API in Azure.
 */
@Fluent
@Beta(Beta.SinceVersion.V1_6_0)
public interface BatchAIJobs extends
        SupportsCreating<BatchAIJob.DefinitionStages.Blank>,
        SupportsListing<BatchAIJob>,
        SupportsGettingByName<BatchAIJob>,
        SupportsGettingById<BatchAIJob>,
        SupportsGettingByNameAsync<BatchAIJob>,
        SupportsDeletingByName,
        SupportsDeletingById,
        HasInner<JobsInner>,
        HasManager<BatchAIManager>,
        HasParent<BatchAIExperiment> {
    /**
     * List Batch AI jobs.
     * @param maxResults maximum number of results
     * @return jobs  list
     */
    PagedList<BatchAIJob> list(int maxResults);
}
